@@ -1,7 +1,7 @@
 package App::MadEye::Plugin::Notify::Email;
 use strict;
 use warnings;
-use base qw/Class::Component::Plugin/;
+use base qw/App::MadEye::Plugin::Base/;
 use Params::Validate;
 use MIME::Lite;
 use DateTime;
@@ -10,6 +10,7 @@ sub notify : Hook('notify') {
     my ($self, $context, $args) = @_;
 
     my $conf = $self->{config}->{config};
+    my $subject   = $conf->{subject} || '%s alert !!!';
     my $from_addr = $conf->{from_addr} or die "missing from_addr";
     my $to_addr   = $conf->{to_addr} or die "missing to_addr";
 
@@ -19,7 +20,7 @@ sub notify : Hook('notify') {
         my $mail = MIME::Lite->new(
             'To'        => $from_addr,
             'From'      => $to_addr,
-            'Subject'   => "$plugin alert !!!",
+            'Subject'   => sprintf($subject, $plugin),
             'Data'      => $self->_format( $plugin, $results ),
         );
         # warn $mail->as_string;
@@ -40,3 +41,27 @@ sub _format {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+App::MadEye::Plugin::Notify::Email - notify by email
+
+=head1 SCHEMA
+
+    type: map
+    mapping:
+        subject:
+            type: str
+            required: no
+        from_addr:
+            type: str
+            required: yes
+        to_addr:
+            type: str
+            required: yes
+
+=head1 SEE ALSO
+
+L<App::MadEye>, L<MIME::Lite>
+
