@@ -3,32 +3,40 @@ use strict;
 use warnings;
 use base qw/Exporter/;
 
-our @EXPORT = qw/timeout log_stopwatch get_schema_from_pod/;
+our @EXPORT = qw/timeout get_schema_from_pod context snmp_session/;
 
 use Sys::Syslog qw/:DEFAULT/;
 use Pod::POM ();
 use List::Util qw/first/;
 use YAML ();
 use Time::HiRes qw/gettimeofday/;
+use Net::SNMP;
+
+sub context () { App::MadEye->context } ## no critic.
 
 sub timeout($$&) {    ## no critic.
     my ( $secs, $msg, $code ) = @_;
-    App::MadEye->context->log(debug => "run timer: '$msg', $secs");;
+
+    context->log(debug => "run timer: '$msg', $secs");;
+
     my $last_alarm = 0;
+    my $err;
     eval {
         local $SIG{ALRM} = sub { die "Time out error: $msg" };
         $last_alarm = alarm $secs;
 
         my $start_time = gettimeofday();
             $code->();
-        App::MadEye->context->log('debug' => "stopwatch: " . (gettimeofday() - $start_time));
+        context->log('debug' => "stopwatch: " . (gettimeofday() - $start_time));
     };
     if ($@) {
-        my $err = $@;
-        App::MadEye->context->log('error' => $err);
-        warn $err;
+        $err = $@;
+
+        context->log('error' => $err);
     }
     alarm $last_alarm; # restore
+
+    return $err;
 }
 
 sub get_schema_from_pod {
@@ -47,4 +55,28 @@ sub get_schema_from_pod {
     }
 }
 
+sub snmp_session {
+    my ($agent, $host, $callback, ) = @_;
+
+    my $community = $agent->config->{config}->{community} or die "missing community";
+    my $port      = $agent->config->{config}->{port}    || 161;
+    my $timeout   = $agent->config->{config}->{timeout} || 10;
+
+    my ($session, $error) = Net::SNMP->session(
+        -hostname  => $host,
+        -community => $community,
+        -port      => $port,
+        -timeout   => $timeout,
+    );
+
+    if (not defined($session)) {
+        die "ERROR: $error.\n";
+    } else {
+        my $response = $callback->($session);
+        $session->close();
+        return $response;
+    }
+}
+
+
 1;
